% SimulinkADCExample: Example continuous-time sigma-delta ADC
% Copyright (c) 2008 Poojan Wagh (poojanwagh {at} circuitdesign {dot} info)
% This file is part of SimulinkADCExample.
%
%     SimulinkADCExample is free software: you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation, either version 3 of the License, or
%     (at your option) any later version.
%
%     SimulinkADCExample is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
%
%     You should have received a copy of the GNU General Public License
%     along with SimulinkADCExample.  If not, see <http://www.gnu.org/licenses/>.
clear all;              % reset everything
fmod = 8E3;             % 8 kHz (arbitrary) input frequency
nmod = 4096;            % number of cycles of fmod to simulate
kmod = 1024;            % number of cycles of fmod to leave for startup
osr = 64;               % over-sampling ratio
acmag = 0.5;            % small input (don't want to overload)
F1 = 40E3;              % Arbitrarily chosen
F2 = 20E3;              % Arbitrarily chosen
A1 = 0;                 % Do not simulate finite gain of integrators
A2 = 0;                 % Do not simulate finite gain of integrators


tQ = 1/(2*osr*fmod);

sim('sigmadelta_adc');       % run Simulink model
psd(yout)

lasty = yout(length(yout)-osr*nmod+1:length(yout));     % limit to last osr*nmod samples
Pout = fft(lasty, osr*nmod);
F = (0:osr*nmod-1) / (osr*nmod*tQ);
plot(F, 20*log10(abs(Pout)))
